/*
 * Copyright (c) 2004 by Beacon Information Technology, Inc.
 *
 * Licensor (Beacon IT) hereby grants You a world-wide, royalty-free,
 * non-exclusive, perpetual, sublicenseable license to do the
 * following:
 *
 *    1. to reproduce the Original Work in copies;
 *    2. to prepare derivative works ("Derivative Works") based
 *       upon the Original Work;
 *    3. to distribute copies of the Original Work and Derivative
 *       Works to the public; and
 *    4. to display the Original Work publicly. 
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package portlets;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Enumeration;
import java.util.Vector;

import javax.portlet.PortletPreferences;
import javax.portlet.PreferencesValidator;
import javax.portlet.ValidatorException;

/**
 * BirthdaysPreferencesValidatorはBirthdaysPortletのポートレットプリファレンスの
 * 値を確認するサンプルです。
 *
 * プリファレンスが 2つあります:
 * <ul>
 *   <li>list-by - { "name", "team", "birthplace" }</li>
 *   <li>name-type - { "full", "reg" }</li>
 * </ul>
 *
 * プロパティの値が以上のセット以外なら、例外を投げます。
 *
 * @author ウェストベイ マイケル 技師 [(株)ビーコンIT プロダクト開発部]
 * @version 1.0
 */
public class BirthdaysPreferencesValidator implements PreferencesValidator {

    /** list-byの有効な値です。 */
    private static Vector LIST_BY_VALUES = new Vector();
            
    /** name-typeの有効な値です。 */
    private static Vector NAME_TYPE_VALUES = new Vector();

    // static変数を初期化する
    static {
        LIST_BY_VALUES.add("name");
        LIST_BY_VALUES.add("team");
        LIST_BY_VALUES.add("birthplace");
        NAME_TYPE_VALUES.add("full");
        NAME_TYPE_VALUES.add("reg");
    }
    
    /**
     * プリファレンスの値が有効なリストに指定されている場合、そのままで
     * 戻します。無効な値がある場合 {@link ValidatorException}を投げます。
     * 
     * @param  prefs 確認するプリファレンスコレクションです。
     * @throws ValidatorException 無効な値が指定されている場合、この例外
     *         を投げます。
     */
    public void validate(PortletPreferences prefs)
            throws ValidatorException {
        
        // 失敗したのプリファレンスのキーコレクション
        Collection failedKeys = new ArrayList();

        // キーと値の変数
        String key = null;
        String value = null;

        // すべてプリファレンスキー・値ペアを処理する
        for (Enumeration e = prefs.getNames(); e.hasMoreElements(); ) {
            key = e.nextElement().toString();
            value = prefs.getValue(key, null);

            // nullの値が大丈夫 - チェックが不要です
            if (value != null) {
                // list-byの値チェック
                if ("list-by".equals(key)) {
                    if (!LIST_BY_VALUES.contains(value)) {
                        failedKeys.add(key);
                    }
                }

                // name-typeの値チェック
                else if ("name-type".equals(key)) {
                    if (!NAME_TYPE_VALUES.contains(value)) {
                        failedKeys.add(key);
                    }
                }
            }
        }

        // 一つ以上のキーが失敗したら、例外を投げる
        if (!failedKeys.isEmpty()) {
            throw new ValidatorException("Invalid preferences",
                failedKeys);
        }
    }
}
